@@ -4,6 +4,7 @@
 #' Fast Gibbs sampler in C++ that is tailored to the standard MPT model (i.e., fixed-effects, non-hierarchical MPT: assumes separate parameters if multiple data sets are supplied).
 #'
 #' @inheritParams betaMPT
+#' @inheritParams betaMPTcpp
 #' @param alpha first shape parameter(s) for the beta prior-distribution of the MPT parameters \eqn{\theta_s} (can be a named vector to use a different prior for each MPT parameter)
 #' @param beta second shape parameter(s)
 #' @details Beta distributions with fixed shape parameters \eqn{\alpha} and \eqn{\beta} are used. The default \eqn{\alpha=1} and \eqn{\beta=1} assumes uniform priors for all MPT parameters.
@@ -22,10 +23,11 @@
 #' }
 #' @export
 simpleMPT <- function(eqnfile, data, restrictions,
-                      n.iter=20000, n.burnin = 2000,
-                      n.thin = 5,  n.chains=3, ppp = 0,
+                      n.iter=2000, n.burnin = 500,
+                      n.thin = 3,  n.chains=3, ppp = 0,
                       alpha = 1, beta = 1,
-                      parEstFile, posteriorFile){
+                      parEstFile, posteriorFile,
+                      cores = 1){
 
   hyperprior <- list(alpha=alpha, beta=beta)
   if(!is.character(data) && is.null(dim(data))){
@@ -40,7 +42,8 @@ simpleMPT <- function(eqnfile, data, restrictions,
                              n.chains=n.chains,  ppp = ppp,
                              parEstFile=parEstFile,
                              posteriorFile=posteriorFile,
-                             call = match.call())
+                             call = match.call(),
+                             cores = cores)
 
   fittedModel
 }
