@@ -10,6 +10,7 @@
 #' @param select a numeric vector with participant indices to select which raw frequencies to plot (default: \code{"all"})
 #' @param boxplot if \code{FALSE}, lines and points are drawn instead of boxplots
 #' @param eqn optional: EQN description of an MPT model, that is, either the path to an EQN file or as a character string (only used if \code{x} refers to a matrix/data frame or .csv-file)
+#' @param ... further arguments passed to \code{boxplot} and \code{plot}
 #' @export
 #' @examples
 #' # get frequency data and EQN file
@@ -17,7 +18,7 @@
 #' eqn <- EQNfile <- system.file("MPTmodels/2htsm.eqn", package="TreeBUGS")
 #' plotFreq(freq, eqn = eqn)
 #' plotFreq(freq, freq = FALSE, eqn = eqn)
-plotFreq <- function(x, freq=TRUE, select="all", boxplot=TRUE, eqn){
+plotFreq <- function(x, freq=TRUE, select="all", boxplot=TRUE, eqn,...){
 
 
   if(class(x) %in% c("betaMPT", "traitMPT")){
@@ -65,10 +66,10 @@ plotFreq <- function(x, freq=TRUE, select="all", boxplot=TRUE, eqn){
 
   if(boxplot == TRUE){
     boxplot(dat, ylab=ifelse(freq, "Absolute frequency", "Relative frequency (per tree)"),
-            xlab="", main=ifelse(freq, "Absolute frequency", "Relative frequency (per tree)"))
+            xlab="", main=ifelse(freq, "Absolute frequency", "Relative frequency (per tree)"), las=1, ...)
     lines(1:K, means, col="red", lwd=2)
   }else{
-    plot(1:K, means, ylim=c(0, max(dat)), col=1, lwd=3, pch=16, xaxt="n",
+    plot(1:K, means, ylim=c(0, max(dat)), col=1, lwd=3, pch=16, xaxt="n", las=1, ...,
          ylab=ifelse(freq, "Absolute frequency", "Relative frequency (per tree)"),
          xlab="", main=ifelse(freq, "Absolute frequency", "Relative frequency (per tree)"))
     axis(1, 1:K, colnames(dat))
