@@ -2,8 +2,8 @@
 #'
 #' Function to import MPT models from standard .eqn model files as used, for instance, by multiTree (Moshagen, 2010).
 #'
-#' @param file The (full path to the) file that specifies the MPT model (standard .eqn syntax). Note that category labels must start with a letter (different to multiTree) and match the column names of \code{data}. Alternatively, the EQN-equations can be provided within R as a character value (see examples).
-#' @param restrictions Optional: The (full path to the) file that specifies which parameters should be constants and which should be equal. Alternatively: a list of restrictions, e.g., \code{list("D1=D2","g=0.5")}
+#' @param file The (full path to the) file that specifies the MPT model (standard .eqn syntax). Note that category labels must start with a letter (different to multiTree) and match the column names of \code{data}. Alternatively, the EQN-equations can be provided within R as a character value (see examples). Note that the first line of an .eqn-file is reserved for comments and always ignored.
+#' @inheritParams betaMPT
 #' @param paramOrder if TRUE, the order of MPT parameters as interally used is printed.
 #' @param parse whether to return a parsed MPT model description in terms of the matrices \eqn{a} and \eqn{b} (the powers of the \eqn{\theta} and \eqn{(1-\theta)}, respectively, and the vector of constants \eqn{c}. Each branch probability is then given as \eqn{c_{i}  \prod_{s} \theta^{a_{i,s}}(1-\theta)^{b_{i,s}})}
 #' @details The file format should adhere to the standard .eqn-syntax (note that the first line is skipped and can be used for comments). In each line, a separate branch of the MPT model is specified using the tree label, category label, and the model equations in full form (multiplication sign `*` required; not abbreviations such as `a^2` allowed).
@@ -42,10 +42,8 @@
 #' @author Daniel Heck, Denis Arnold, Nina Arnold
 #' @references Moshagen, M. (2010). multiTree: A computer program for the analysis of multinomial processing tree models. Behavior Research Methods, 42, 42-54.
 #' @export
-readEQN <- function(file,
-                    restrictions=NULL,
-                    paramOrder = FALSE,
-                    parse=FALSE){
+readEQN <- function(file, restrictions=NULL, paramOrder = FALSE, parse=FALSE){
+
   if(missing(restrictions)) restrictions <- NULL
 
   isPath <- !grepl("\n", x=file, ignore.case = TRUE)
@@ -54,17 +52,19 @@ readEQN <- function(file,
     file <- tempfile(pattern = "MPTmodel", tmpdir = tempdir(), fileext = ".eqn")
     cat(paste0(model,"\n"), file=file)
   }
-  multiTreeDefinition <- read.csv(file, header=F,
-                                  blank.lines.skip = TRUE, sep= "",
-                                  stringsAsFactors=F, skip = 1)
-
+  # read first line if it contains model equations
+  nvars <- max(count.fields(file, sep = "", skip = 1))
+  multiTreeDefinition <- read.csv(file, header = FALSE, comment.char = "#",
+                                  blank.lines.skip = TRUE, sep= "", strip.white = TRUE,
+                                  stringsAsFactors = FALSE, skip = 1,
+                                  col.names = paste0("V",seq(nvars)))
 
   # number of branches implied by number of rows in model file:
   numberOfBranches <- nrow(multiTreeDefinition)
   cols <- ncol(multiTreeDefinition)
   Tree <- data.frame(Tree = paste0("T_",multiTreeDefinition$V1),
                      Category = multiTreeDefinition$V2,
-                     Equation = multiTreeDefinition$V3)
+                     Equation = NA_character_)
   Tree$Equation <- apply(multiTreeDefinition[,3:cols, drop=FALSE], 1, paste0, collapse="")
 
   TreeRestr <- thetaHandling(Tree, restrictions)
@@ -113,7 +113,8 @@ readEQN <- function(file,
   }
   if(any(round(sumPerTree,8) != 1)){
     error <- paste0("Check .eqn-file. Probabilities do not sum up in trees:\n  ",
-                    paste0(unique(Tree$Tree)[round(sumPerTree,8) != 1], collapse=", "))
+                    paste0(unique(Tree$Tree)[round(sumPerTree,8) != 1], collapse=", "),
+                    "\n  (note that the first line of the .eqn-file ist ignored!)")
     warning(error)
   }
 
